@@ -22,30 +22,6 @@ def dataclass_dict(__v):
     return __encode(__v)
 
 
-def jsonify_test_profiles(tp):
-    import json
-
-    def dcdict(__obj):
-        return {key: getattr(__obj, key) for key in __obj.__dataclass_fields__.keys()}
-
-    def test_profile_dict(__tp):
-        result = dcdict(__tp)
-        result["time"] = dcdict(result["time"])
-        return result
-
-    def test_profiles_dict(__tp):
-        return {
-            "data": {
-                "times": [dcdict(tt) for tt in __tp.data.times],
-                "tests": [test_profile_dict(tt) for tt in __tp.data.tests],
-            },
-            "meta": dcdict(__tp.data.meta),
-        }
-
-    tpdict = test_profiles_dict(tp)
-    return json.dumps(tpdict, indent=4)
-
-
 @dataclass(frozen=False, order=True)
 class Test:
     name: str
@@ -99,6 +75,10 @@ class TestProfiles:
     data: Data
 
 
+
+    def json(self,indent:int=4):
+        return json.dumps(dataclass_dict(self),indent=indent)
+
 @dataclass(frozen=False, order=True)
 class TestResults:
     data: List[TestResult]
